You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by am...@apache.org on 2021/02/04 14:38:20 UTC

[ignite-3] branch main updated: Fix typos.

This is an automated email from the ASF dual-hosted git repository.

amashenkov pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/ignite-3.git


The following commit(s) were added to refs/heads/main by this push:
     new 8de4c5d  Fix typos.
8de4c5d is described below

commit 8de4c5df9dd05b9c76e7fe242178c5e82c0e7a48
Author: Andrew Mashenkov <an...@gmail.com>
AuthorDate: Thu Feb 4 17:38:08 2021 +0300

    Fix typos.
---
 .../apache/ignite/cli/builtins/module/MavenArtifactResolver.java  | 8 ++++----
 .../org/apache/ignite/rest/presentation/json/JsonConverter.java   | 2 +-
 pom.xml                                                           | 2 +-
 3 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/modules/rest/src/main/java/org/apache/ignite/rest/presentation/json/JsonConverter.java b/modules/rest/src/main/java/org/apache/ignite/rest/presentation/json/JsonConverter.java
index 4156f14..555e406 100644
--- a/modules/rest/src/main/java/org/apache/ignite/rest/presentation/json/JsonConverter.java
+++ b/modules/rest/src/main/java/org/apache/ignite/rest/presentation/json/JsonConverter.java
@@ -48,7 +48,7 @@ public class JsonConverter implements FormatConverter {
     @Override public String rootName(String source) {
         Map<String, Object> map = gson.fromJson(source, Map.class);
 
-        // Peek only first root for simplicite. See comment in ConfigurationPresentation#update for more context.
+        // Peek only first root for simplicity. See comment in ConfigurationPresentation#update for more context.
         Optional<String> firstOpt = map.keySet().stream().findFirst();
 
         return firstOpt.isPresent() ? firstOpt.get() : null;
diff --git a/pom.xml b/pom.xml
index 6ce3c26..abf5ce6 100644
--- a/pom.xml
+++ b/pom.xml
@@ -46,7 +46,7 @@
         <plugins>
             <!--
               This plugin is used for checking that all files in project are compliant with target licenses headers.
-              Exlusions are possible, but every exclusion should have it's own motivated comment and/or issue key.
+              Exclusions are possible, but every exclusion should have it's own motivated comment and/or issue key.
             -->
             <plugin>
                 <groupId>org.apache.rat</groupId>
diff --git a/modules/cli/src/main/java/org/apache/ignite/cli/builtins/module/MavenArtifactResolver.java b/modules/cli/src/main/java/org/apache/ignite/cli/builtins/module/MavenArtifactResolver.java
index 384185f..3f2ce1b 100644
--- a/modules/cli/src/main/java/org/apache/ignite/cli/builtins/module/MavenArtifactResolver.java
+++ b/modules/cli/src/main/java/org/apache/ignite/cli/builtins/module/MavenArtifactResolver.java
@@ -99,7 +99,7 @@ public class MavenArtifactResolver {
      * @param mavenRoot Path where artifacts will be copied to.
      * @param grpId Maven group id of the artifact.
      * @param artifactId Maven artifact id of the artifact.
-     * @param ver Manve version of the artifact.
+     * @param ver Maven version of the artifact.
      * @param customRepositories Urls with custom maven repositories to resolve artifact.
      * @return Result of resolving with files' paths of resolved artifact + dependencies.
      * @throws IOException if connection issues occurred during resolving
@@ -175,15 +175,15 @@ public class MavenArtifactResolver {
      * <p>
      * Note: Current implementation doesn't support artifacts with classifiers or non-jar packaging
      *
      * @param artfactId Maven artifact id.
      * @param ver Maven version
      * @return File name
      */
     public static String fileNameByArtifactPattern(
-        String artfactId,
+        String artifactId,
         String ver) {
         return FILE_ARTIFACT_PATTERN
-            .replace("[artifact]", artfactId)
+            .replace("[artifact]", artifactId)
             .replace("(-[classifier])", "")
             .replace("[revision]", ver)
             .replace("[ext]", "jar");
@@ -175,15 +175,15 @@ public class MavenArtifactResolver {
      * Note: Current implementation doesn't support artifacts with classifiers or non-jar packaging
      *
-     * @param artfactId Maven artifact id.
+     * @param artifactId Maven artifact id.
      * @param ver Maven version
      * @return File name